用户信息页面 - Bootstrap后台管理系统模版Ace下载
Description: 站长素材提供Bootstrap模版,Bootstrap教程,Bootstrap中文翻译等相关Bootstrap插件下载
Keywords: Bootstrap模版,Bootstrap模版下载,Bootstrap教程,Bootstrap中文

# User Profile Page 3 styles with inline editable feature

Click on the image below or on profile fields to edit them ...
Choose profile:
1 2 3
Alex M. Doe
Add as a friend Send a message www.alexdoe.com
25
Followers
12
Following
1,411
Views 32
Followers 4
Projects 23
Reviews 7
Albums 55
Contacts
Username
alexdoe
Location
Netherlands Amsterdam
Age
38
Joined
20/06/2010
Last Online
3 hours ago
About Me
Editable as WYSIWYG

#### Recent Activities

Alex Doe changed his profile photo. Take a look
an hour ago
Susan Smith is now friends with Alex Doe.
2 hours ago
Alex Doe joined Country Music group.
5 hours ago
Alex Doe uploaded a new photo. Take a look
5 hours ago
David Palms left a comment on Alex's wall.
8 hours ago
Alex Doe published a new blog post. Read now
11 hours ago
Alex Doe upgraded his skills.
12 hours ago
Alex Doe logged in.
12 hours ago
Alex Doe logged out.
16 hours ago
Alex Doe logged in.
16 hours ago
View more activities
Add as a friend Send a message

#### Alex M. Doe online

Username
alexdoe
Location
Netherlands Amsterdam
Age
38
Joined
20/06/2010
Last Online
3 hours ago
Website
www.alexdoe.com
Find me on Facebook
Follow me on Twitter

#### Little About Me

My job is mostly lorem ipsuming and dolor sit ameting as long as consectetur adipiscing elit.

Sometimes quisque commodo massa gets in the way and sed ipsum porttitor facilisis.

The best thing about my job is that vestibulum id ligula porta felis euismod and nullam quis risus eget urna mollis ornare.

Thanks for visiting my profile.

#### My Skills

45%
Graphic Design
90%
HTML5 & CSS3
80%
Javascript/jQuery
HTML5 & CSS3 80%
Javascript & jQuery 72%
PHP & MySQL 70%
Wordpress 50%
Photoshop 35%
Alex Doe changed his profile photo. Take a look
an hour ago
Susan Smith is now friends with Alex Doe.
2 hours ago
Alex Doe joined Country Music group.
5 hours ago
Alex Doe uploaded a new photo. Take a look
5 hours ago
David Palms left a comment on Alex's wall.
8 hours ago
Alex Doe published a new blog post. Read now
11 hours ago
Alex Doe upgraded his skills.
12 hours ago
Alex Doe logged in.
12 hours ago
Alex Doe logged out.
16 hours ago
Alex Doe logged in.
16 hours ago
View more activities
Bob Doe
Content Editor
20 mins ago
Rose Doe
Graphic Designer
30 min ago
Jim Doe
SEO & Advertising
1 hour ago
Alex Doe
Marketing
40 minutes idle
Phil Doe
Public Relations
2 hours ago
Susan Doe
HR Management
20 mins ago
Jennifer Doe
Graphic Designer
2 hours ago
Alexa Doe
Accounting
4 hours ago

- ← Prev
- Next →

- Sample Caption on Hover
- Sample Caption on Hover
- Sample Caption on Hover
- Sample Caption on Hover
- Sample Caption on Hover
- Sample Caption on Hover
- Sample Caption on Hover
- Sample Caption on Hover

Your profile is 70% complete

#### General

Username
Name

Birth Date
Gender
Male Female
Comment

#### Contact

Email
Website
Phone

#### Social

Facebook
Twitter
Google+
Make my profile public
Email me new updates
Keep a history of my conversations for days
New Password
Confirm Password
Choose Skin
Fixed Navbar
Fixed Sidebar
Fixed Breadcrumbs
Right To Left (rtl)
Inside .container